Index: packages/analyzer/lib/src/generated/utilities_general.dart |
diff --git a/analyzer/lib/src/generated/utilities_general.dart b/packages/analyzer/lib/src/generated/utilities_general.dart |
similarity index 94% |
rename from analyzer/lib/src/generated/utilities_general.dart |
rename to packages/analyzer/lib/src/generated/utilities_general.dart |
index 62f40293d286a7a2c6c8e935809ebd6a8944c51f..d120a81abdd6e0a9b12554d53bbb5c556f21071f 100644 |
--- a/analyzer/lib/src/generated/utilities_general.dart |
+++ b/packages/analyzer/lib/src/generated/utilities_general.dart |
@@ -2,12 +2,9 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-// This code was auto-generated, is not intended to be edited, and is subject to |
-// significant change. Please see the README file for more information. |
- |
library engine.utilities.general; |
-import 'dart:profiler'; |
+import 'dart:developer' show UserTag; |
/** |
* Jenkins hash function, optimized for small integers. |
@@ -36,7 +33,7 @@ class JenkinsSmiHash { |
/** |
* Helper class for gathering performance statistics. This class is modeled on |
* the UserTag class in dart:profiler so that it can interoperate easily with |
* it. |
*/ |
abstract class PerformanceTag { |
@@ -36,7 +33,7 @@ class JenkinsSmiHash { |
/** |
* Helper class for gathering performance statistics. This class is modeled on |
- * the UserTag class in dart:profiler so that it can interoperate easily with |
+ * the UserTag class in dart:developer so that it can interoperate easily with |
* it. |
*/ |